==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebComponentDataValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentDataValueChangedEventArgsDescription } from "./WebComponentDataValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let WebComponentDataValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebComponentDataValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebComponentDataValueChangedEventArgsDescriptionMetadata.a == null) {
                WebComponentDataValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebComponentDataValueChangedEventArgsDescriptionMetadata.c(WebComponentDataValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebComponentDataValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebComponentDataValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ComponentDataValueChangedEventArgs");
            a.item("Detail", "Unknown");
        }
        static d(a) {
            WebComponentDataValueChangedEventArgsDescriptionMetadata.b(a);
            a.aa("WebComponentDataValueChangedEventArgs", () => new WebComponentDataValueChangedEventArgsDescription());
            a.z("WebComponentDataValueChangedEventArgs", WebComponentDataValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    WebComponentDataValueChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebComponentDataValueChangedEventArgsDescriptionMetadata, 'WebComponentDataValueChangedEventArgsDescriptionMetadata');
    WebComponentDataValueChangedEventArgsDescriptionMetadata.a = null;
    return WebComponentDataValueChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebComponentDataValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentDataValueChangedEventArgsDescription } from "./WebComponentDataValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let WebComponentDataValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebComponentDataValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebComponentDataValueChangedEventArgsDescriptionMetadata.a == null) {
                WebComponentDataValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebComponentDataValueChangedEventArgsDescriptionMetadata.c(WebComponentDataValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebComponentDataValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebComponentDataValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ComponentDataValueChangedEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Detail", "Unknown");
        }
        static d(a) {
            WebComponentDataValueChangedEventArgsDescriptionMetadata.b(a);
            a.ac("WebComponentDataValueChangedEventArgs", () => new WebComponentDataValueChangedEventArgsDescription());
            a.ab("WebComponentDataValueChangedEventArgs", WebComponentDataValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    WebComponentDataValueChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebComponentDataValueChangedEventArgsDescriptionMetadata, 'WebComponentDataValueChangedEventArgsDescriptionMetadata');
    WebComponentDataValueChangedEventArgsDescriptionMetadata.a = null;
    return WebComponentDataValueChangedEventArgsDescriptionMetadata;
})();
